@@ -1,23 +1,19 @@
+from .primitives import Buffer
 from .request import Request
 from .response import Response
-from .primitives import Buffer
 
 
 class SASLRequest(Request):
-    """
-    """
+    """ """
+
     opcode = 102
 
-    parts = (
-        ("token", Buffer)
-    )
+    parts = ('token', Buffer)
 
 
 class SASLResponse(Response):
-    """
-    """
+    """ """
+
     opcode = 102
 
-    parts = (
-        ("token", Buffer)
-    )
+    parts = ('token', Buffer)
