@@ -2,17 +2,18 @@ import asyncio
 import collections
 import inspect
 import logging
+from typing import ClassVar
 
 from aiozk import WatchEvent, exc
 
 from .recipe import Recipe
 
+
 log = logging.getLogger(__name__)
 
 
 class BaseWatcher(Recipe):
-
-    watched_events = []
+    watched_events: ClassVar = []
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -37,14 +38,14 @@ class BaseWatcher(Recipe):
 
     async def watch_loop(self, path):
         while self.callbacks[path]:
-            log.debug("Fetching data for %s", path)
+            log.debug('Fetching data for %s', path)
             watch_future = self.client.wait_for_events(self.watched_events, path)
             try:
                 result = await self.fetch(path)
             except exc.NoNode:
                 result = exc.NoNode
             except exc.ZKError as e:
-                log.exception('Exception in watch loop: {}'.format(e))
+                log.exception('Exception in watch loop: %s', e)
                 log.info('Waiting for safe state...')
                 await self.client.session.ensure_safe_state()
                 continue
@@ -55,7 +56,7 @@ class BaseWatcher(Recipe):
             for callback in self.callbacks[path].copy():
                 maybe_coroutine = callback(result)
                 if inspect.iscoroutine(maybe_coroutine):
-                    asyncio.create_task(maybe_coroutine)
+                    _ = asyncio.create_task(maybe_coroutine)  # noqa: RUF006
             if WatchEvent.CREATED not in self.watched_events and result == exc.NoNode:
                 return
             try:
