@@ -1,17 +1,17 @@
 import asyncio
 import logging
 import time
+from functools import partial
 
 from aiozk import exc
 
 from .sequential import SequentialRecipe
-from functools import partial
+
 
 log = logging.getLogger(__name__)
 
 
 class Lease(SequentialRecipe):
-
     def __init__(self, base_path, limit=1):
         super().__init__(base_path)
         self.limit = limit
@@ -25,9 +25,9 @@ class Lease(SequentialRecipe):
         time_limit = time.time() + duration.total_seconds()
 
         try:
-            await self.create_unique_znode("lease", data=str(time_limit))
+            await self.create_unique_znode('lease', data=str(time_limit))
         except exc.NodeExists:
-            log.warning("Lease for %s already obtained.", self.base_path)
+            log.warning('Lease for %s already obtained.', self.base_path)
 
         callback = partial(asyncio.create_task, self.release())
         loop = asyncio.get_running_loop()
@@ -35,4 +35,4 @@ class Lease(SequentialRecipe):
         return True
 
     async def release(self):
-        await self.delete_unique_znode("lease")
+        await self.delete_unique_znode('lease')
