@@ -1,20 +1,20 @@
 import asyncio
 import logging
+from typing import ClassVar
 
+from ..exc import NoNode
 from .children_watcher import ChildrenWatcher
 from .data_watcher import DataWatcher
 from .recipe import Recipe
-from ..exc import NoNode
 
 
 log = logging.getLogger(__name__)
 
 
 class TreeCache(Recipe):
-
-    sub_recipes = {
-        "data_watcher": DataWatcher,
-        "child_watcher": ChildrenWatcher,
+    sub_recipes: ClassVar = {
+        'data_watcher': DataWatcher,
+        'child_watcher': ChildrenWatcher,
     }
 
     def __init__(self, base_path, defaults=None):
@@ -24,11 +24,14 @@ class TreeCache(Recipe):
         self.root = None
 
     async def start(self):
-        log.debug("Starting znode tree cache at %s", self.base_path)
+        log.debug('Starting znode tree cache at %s', self.base_path)
 
         self.root = ZNodeCache(
-            self.base_path, self.defaults,
-            self.client, self.data_watcher, self.child_watcher,
+            self.base_path,
+            self.defaults,
+            self.client,
+            self.data_watcher,
+            self.child_watcher,
         )
 
         await self.ensure_path()
@@ -46,7 +49,6 @@ class TreeCache(Recipe):
 
 
 class ZNodeCache:
-
     def __init__(self, path, defaults, client, data_watcher, child_watcher):
         self.path = path
 
@@ -61,7 +63,7 @@ class ZNodeCache:
 
     @property
     def dot_path(self):
-        return self.path[1:].replace("/", ".")
+        return self.path[1:].replace('/', '.')
 
     @property
     def value(self):
@@ -77,8 +79,11 @@ class ZNodeCache:
         self.data = await self.client.get_data(self.path)
         for child in await self.client.get_children(self.path):
             self.children[child] = ZNodeCache(
-                self.path + "/" + child, self.defaults.get(child, {}),
-                self.client, self.data_watcher, self.child_watcher
+                self.path + '/' + child,
+                self.defaults.get(child, {}),
+                self.client,
+                self.data_watcher,
+                self.child_watcher,
             )
 
         await asyncio.gather(*(child.start() for child in self.children.values()))
@@ -99,28 +104,28 @@ class ZNodeCache:
         added_children = set(new_children) - set(self.children.keys())
 
         for removed in removed_children:
-            log.debug("Removed child %s", self.dot_path + "." + removed)
+            log.debug('Removed child %s', self.dot_path + '.' + removed)
             child = self.children.pop(removed)
             await child.stop()
 
         for added in added_children:
-            log.debug("Added child %s", self.dot_path + "." + added)
+            log.debug('Added child %s', self.dot_path + '.' + added)
             self.children[added] = ZNodeCache(
-                self.path + "/" + added, self.defaults.get(added, {}),
-                self.client, self.data_watcher, self.child_watcher
+                self.path + '/' + added,
+                self.defaults.get(added, {}),
+                self.client,
+                self.data_watcher,
+                self.child_watcher,
             )
         await asyncio.gather(*(self.children[added].start() for added in added_children))
 
     async def data_callback(self, data):
-        log.debug("New value for %s: %r", self.dot_path, data)
+        log.debug('New value for %s: %r', self.dot_path, data)
         if data == NoNode:
             return
         self.data = data
 
     def as_dict(self):
         if self.children:
-            return {
-                child_path: child_znode.as_dict()
-                for child_path, child_znode in self.children.items()
-            }
+            return {child_path: child_znode.as_dict() for child_path, child_znode in self.children.items()}
         return self.data
