@@ -1,9 +1,12 @@
 import asyncio
 import logging
 import uuid
+from contextlib import suppress
+
 import pytest
 
 from aiozk import WatchEvent
+
 from .conftest import get_client
 
 
@@ -37,43 +40,46 @@ async def test_cancel_crash(zk, path):
 
     task = asyncio.create_task(wait_loop())
     task.cancel()
+    with suppress(asyncio.CancelledError):
+        await task
 
 
 @pytest.mark.asyncio
-async def test_closed_close():
-    zk = get_client()
+async def test_closed_close(servers):
+    zk = get_client(servers)
     await asyncio.wait_for(zk.session.close(), 2)
 
 
-
 @pytest.mark.asyncio
-async def test_inconsistent_zxid():
+async def test_inconsistent_zxid(servers):
     async def coro():
-        zk = get_client()
+        zk = get_client(servers)
         await zk.start()
         # simulate failed connection
         await zk.session.close()
         zk.session.last_zxid = 1231231241312312
         await zk.session.start()
         await zk.session.close()
+
     try:
         await asyncio.wait_for(coro(), timeout=10)
-    except asyncio.TimeoutError as exc:
-        pytest.fail("Failed with timeout on session reconnection attemt")
+    except asyncio.TimeoutError:
+        pytest.fail('Failed with timeout on session reconnection attemt')
 
 
 @pytest.mark.asyncio
-async def test_session_reconnect():
+async def test_session_reconnect(servers):
     async def coro():
-        zk = get_client()
+        zk = get_client(servers)
         await zk.start()
         await zk.session.close()
         await zk.session.start()
         await zk.session.close()
+
     try:
         await asyncio.wait_for(coro(), timeout=10)
-    except asyncio.TimeoutError as exc:
-        pytest.fail("Failed with timeout on session reconnection attemt")
+    except asyncio.TimeoutError:
+        pytest.fail('Failed with timeout on session reconnection attemt')
 
 
 @pytest.mark.asyncio
@@ -84,10 +90,11 @@ async def test_raw_get(full_zk, path):
     assert data is None
     assert stat.version == 0
 
+
 @pytest.mark.asyncio
 async def test_raw_set(full_zk, path):
     # type: (aiozk.ZKClent, str) -> None
     """Test that raw set returns Stat"""
     stat = await full_zk.set(path, 'asdf', -1)
     assert stat.data_length == 4
-    assert stat.version == 1
\ No newline at end of file
+    assert stat.version == 1
